pub struct OperationsWrapperV0_5_0 {
pub sources: Vec<IoRefWrapper>,
pub sinks: Vec<IoRefWrapper>,
pub transforms: TransformsWrapperV0_5_0,
pub post_transforms: Option<PostTransforms>,
pub states: BTreeMap<String, MaybeValid<StateWrapper>>,
}Fields
sources: Vec<IoRefWrapper>sinks: Vec<IoRefWrapper>transforms: TransformsWrapperV0_5_0post_transforms: Option<PostTransforms>states: BTreeMap<String, MaybeValid<StateWrapper>>Trait Implementations
Sourceimpl Clone for OperationsWrapperV0_5_0
impl Clone for OperationsWrapperV0_5_0
Sourcefn clone(&self) -> OperationsWrapperV0_5_0
fn clone(&self) -> OperationsWrapperV0_5_0
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OperationsWrapperV0_5_0
impl Debug for OperationsWrapperV0_5_0
Sourceimpl<'de> Deserialize<'de> for OperationsWrapperV0_5_0
impl<'de> Deserialize<'de> for OperationsWrapperV0_5_0
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OperationsWrapperV0_5_0
impl JsonSchema for OperationsWrapperV0_5_0
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OperationsWrapperV0_5_0
impl RefUnwindSafe for OperationsWrapperV0_5_0
impl Send for OperationsWrapperV0_5_0
impl Sync for OperationsWrapperV0_5_0
impl Unpin for OperationsWrapperV0_5_0
impl UnwindSafe for OperationsWrapperV0_5_0